@@ -17,17 +17,14 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include <math.h>
-#include <config.h>
-
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
-#include <qregexp.h>
-#include <qstring.h>
-
 #include "knumber_priv.h"
 
+#include <math.h>
+#include <config-kcalc.h>
+#include <stdlib.h>
+
+#include <QRegExp>
+
 _knumerror::_knumerror(_knumber const & num)
 {
   switch(num.type()) {
@@ -42,9 +39,7 @@ _knumerror::_knumerror(_knumber const & num)
   }
 }
 
-
-
-_knuminteger::_knuminteger(unsigned long long int num)
+_knuminteger::_knuminteger(quint64 num)
 {
   mpz_init(_mpz);
 #if SIZEOF_UNSIGNED_LONG == 8
@@ -58,7 +53,6 @@ _knuminteger::_knuminteger(unsigned long long int num)
 #endif 
 }
 
-
 _knuminteger::_knuminteger(_knumber const & num)
 {
   mpz_init(_mpz);
@@ -128,7 +122,7 @@ _knumerror::_knumerror(QString const & num)
 _knuminteger::_knuminteger(QString const & num)
 {
   mpz_init(_mpz);
-  mpz_set_str(_mpz, num.ascii(), 10);
+  mpz_set_str(_mpz, num.toAscii(), 10);
 }
 
 _knumfraction::_knumfraction(QString const & num)
@@ -139,7 +133,7 @@ _knumfraction::_knumfraction(QString const & num)
     // first me convert the mantissa
     unsigned long int digits_after_dot = ((num.section( '.', 1, 1)).section('e', 0, 0)).length();
     QString tmp_num = num.section('e', 0, 0).remove('.');
-    mpq_set_str(_mpq, tmp_num.ascii(), 10);
+    mpq_set_str(_mpq, tmp_num.toAscii(), 10);
     mpz_t tmp_int;
     mpz_init(tmp_int);
     mpz_ui_pow_ui (tmp_int, 10, digits_after_dot);
@@ -159,14 +153,14 @@ _knumfraction::_knumfraction(QString const & num)
     }
     mpz_clear(tmp_int);
   } else
-    mpq_set_str(_mpq, num.ascii(), 10);
+    mpq_set_str(_mpq, num.toAscii(), 10);
   mpq_canonicalize(_mpq);
 }
 
 _knumfloat::_knumfloat(QString const & num)
 {
   mpf_init(_mpf);
-  mpf_set_str(_mpf, num.ascii(), 10);
+  mpf_set_str(_mpf, num.toAscii(), 10);
 }
 
 _knuminteger const & _knuminteger::operator = (_knuminteger const & num)
@@ -190,7 +184,7 @@ QString const _knumerror::ascii(int prec) const
   case MinusInfinity:
     return QString("-inf");
   default:
-    return QString::null;
+    return QString();
   }
 }
 
@@ -211,7 +205,6 @@ QString const _knumfraction::ascii(int prec) const
   static_cast<void>(prec);
   char *tmp_ptr = mpq_get_str(0, 10, _mpq);
   QString ret_str = tmp_ptr;
-
   free(tmp_ptr);
 
   return ret_str;
@@ -222,7 +215,7 @@ QString const _knumfloat::ascii(int prec) const
   QString ret_str;
   char *tmp_ptr;
   if (prec > 0)
-    gmp_asprintf(&tmp_ptr, ("%." + QString().setNum(prec) + "Fg").ascii(), _mpf);
+    gmp_asprintf(&tmp_ptr, ("%." + QString().setNum(prec) + "Fg").toAscii(), _mpf);
   else
     gmp_asprintf(&tmp_ptr, "%Fg", _mpf);
 
@@ -343,10 +336,16 @@ int _knumfloat::sign(void) const
 
 
 
-#warning _cbrt for now this is a stupid work around
+#ifdef __GNUC__
+#warning "_cbrt for now this is a stupid work around"
+#endif
 static void _cbrt(mpf_t &num)
 {
+#ifdef Q_CC_MSVC
+  double tmp_num = pow(mpf_get_d(num), 1./3.);
+#else
   double tmp_num = cbrt(mpf_get_d(num));
+#endif
   mpf_init_set_d(num, tmp_num);
 }
 
@@ -567,7 +566,7 @@ _knumber * _knumerror::add(_knumber const & arg2) const
   if (arg2.type() != SpecialType)
     return new _knumerror(_error);
 
-  _knumerror const & tmp_arg2 = dynamic_cast<_knumerror const &>(arg2);
+  _knumerror const & tmp_arg2 = static_cast<_knumerror const &>(arg2);
   
   if (_error == UndefinedNumber  
       || tmp_arg2._error == UndefinedNumber
@@ -638,7 +637,7 @@ _knumber * _knumerror::multiply(_knumber const & arg2) const
   switch(arg2.type()) {
   case SpecialType:
     {
-      _knumerror const & tmp_arg2 = dynamic_cast<_knumerror const &>(arg2);
+      _knumerror const & tmp_arg2 = static_cast<_knumerror const &>(arg2);
       if (_error == UndefinedNumber || tmp_arg2._error == UndefinedNumber)
 	return new _knumerror(UndefinedNumber);
       if ( this->sign() * arg2.sign() > 0)
@@ -943,7 +942,7 @@ int _knumfloat::compare(_knumber const &arg2) const
 
 
 
-_knumerror::operator signed long int (void) const
+_knumerror::operator long int (void) const
 {
   // what would be the correct return values here?
   if (_error == Infinity)
@@ -966,17 +965,17 @@ _knumerror::operator unsigned long int (void) const
 }
 
 
-_knuminteger::operator signed long int (void) const
+_knuminteger::operator long int (void) const
 {
   return mpz_get_si(_mpz);
 }
 
-_knumfraction::operator signed long int (void) const
+_knumfraction::operator long int (void) const
 {
-  return static_cast<signed long int>(mpq_get_d(_mpq));
+  return static_cast<long int>(mpq_get_d(_mpq));
 }
 
-_knumfloat::operator signed long int (void) const
+_knumfloat::operator long int (void) const
 {
   return mpf_get_si(_mpf);
 }
