@@ -6,10 +6,12 @@
 #include <stdio.h>
 
 #include <iostream>
-#include <qstring.h>
+
 
 #include "knumbertest.h"
 
+#include <QString>
+
 QString const  numtypeToString(KNumber::NumType arg)
 {
   switch(arg) {
@@ -30,12 +32,12 @@ QString const  numtypeToString(KNumber::NumType arg)
 void checkResult(QString const &string, KNumber const & result,
 		 QString const & desired_string, KNumber::NumType desired)
 {
-  std::cout << "Testing result of: " << string.ascii() <<
-    " should give " << desired_string.ascii() << " and gives " <<
-    result.toQString(8).ascii() << "....\n";
+  std::cout << "Testing result of: " << string.toAscii().constData() <<
+    " should give " << desired_string.toAscii().constData() << " and gives " <<
+    result.toQString(8).toAscii().constData() << "....\n";
   std::cout << "The type of the result should be " <<
-    numtypeToString(desired).ascii() << " and gives " <<
-    numtypeToString(result.type()).ascii() << "....  ";
+    numtypeToString(desired).toAscii().constData() << " and gives " <<
+    numtypeToString(result.type()).toAscii().constData() << "....  ";
 
   if (result.type() == desired  &&
       result.toQString(8) == desired_string) {
@@ -50,7 +52,7 @@ void checkResult(QString const &string, KNumber const & result,
 void checkTruth(QString const &string, bool computation,
 		bool desired_result)
 {
-  std::cout << "Testing truth of: " << string.ascii() <<
+  std::cout << "Testing truth of: " << string.toAscii().constData() <<
     " should be " << desired_result << " and is " <<
     computation << "....\n";
 
@@ -67,9 +69,9 @@ void checkTruth(QString const &string, bool computation,
 void checkType(QString const &string, KNumber::NumType test_arg,
 	       KNumber::NumType desired)
 {
-  std::cout << "Testing type of: " << string.ascii() << " should give " <<
-    numtypeToString(desired).ascii() << " and gives " <<
-    numtypeToString(test_arg).ascii() << "....";
+  std::cout << "Testing type of: " << string.toAscii().constData() << " should give " <<
+    numtypeToString(desired).toAscii().constData() << " and gives " <<
+    numtypeToString(test_arg).toAscii().constData() << "....";
 
   if (test_arg == desired) {
     std::cout << "OK\n";
@@ -233,7 +235,9 @@ void testingModulus(void)
   checkResult("KNumber(12) % KNumber(0)", KNumber(-12) % KNumber(0), "nan", KNumber::SpecialType);
   checkResult("KNumber(-12) % KNumber(0)", KNumber(-12) % KNumber(0), "nan", KNumber::SpecialType);
 
+#ifdef __GNUC__
 #warning test for other types
+#endif
 
 }
 
@@ -246,7 +250,9 @@ void testingAndOr(void)
   checkResult("KNumber(1023) & KNumber(255)", KNumber(1023) & KNumber(255), "255", KNumber::IntegerType);
   checkResult("KNumber(1023) | KNumber(255)", KNumber(1023) | KNumber(255), "1023", KNumber::IntegerType);
 
+#ifdef __GNUC__
 #warning test for other types
+#endif
 
 }
 
@@ -294,7 +300,9 @@ void testingSqrt(void)
   checkResult("KNumber(-27).cbrt()", KNumber(-27).cbrt(), "-3", KNumber::IntegerType);
   checkResult("KNumber(\"27/8\").cbrt()", KNumber("27/8").cbrt(), "3/2", KNumber::FractionType);
   checkResult("KNumber(\"-8/27\").cbrt()", KNumber("-8/27").cbrt(), "-2/3", KNumber::FractionType);
+#ifdef __GNUC__
 #warning need to check non-perfect cube roots
+#endif
   //  checkResult("KNumber(2).cbrt()", KNumber(2).cbrt(), "1.4142136", KNumber::FloatType);
   //  checkResult("KNumber(\"2/3\").cbrt()", KNumber("2/3").cbrt(), "0.81649658", KNumber::FloatType);
   //  checkResult("KNumber(\"0.25\").cbrt()", KNumber("0.25").cbrt(), "0.5", KNumber::FloatType);
