@@ -566,7 +566,7 @@ void KeysManager::slotGenerateKeyProcess(KgpgInterface *)
 
 void KeysManager::slotGenerateKeyDone(int res, KgpgInterface *interface, const QString &name, const QString &email, const QString &fingerprint)
 {
-    delete interface;
+    interface->deleteLater();
     changeMessage(i18nc("Application ready for user input", "Ready"), 0);
 
     delete pop;
@@ -710,7 +710,7 @@ void KeysManager::slotSetTrustFilter(int i)
 	Q_ASSERT((i >= 0) && (i < 5));
 	switch (i) {
 	case 0:
-		t = TRUST_UNKNOWN;
+		t = TRUST_MINIMUM;
 		break;
 	case 1:
 		t = TRUST_UNDEFINED;
@@ -870,7 +870,7 @@ void KeysManager::slotAddUidFin(int res, KgpgInterface *interface)
 {
     // TODO tester les res
     kDebug(2100) << "Resultat : " << res ;
-    delete interface;
+    interface->deleteLater();
     KGpgNode *nd = iview->selectedNode();
     Q_ASSERT(!(nd->getType() & ~ITYPE_PAIR));
     imodel->refreshKey(static_cast<KGpgKeyNode *>(nd));
@@ -910,7 +910,7 @@ void KeysManager::slotDeletePhoto()
 
 void KeysManager::slotDelPhotoFinished(int res, KgpgInterface *interface)
 {
-    delete interface;
+    interface->deleteLater();
 
     // TODO : add res == 3 (bad passphrase)
 
@@ -1455,7 +1455,7 @@ void KeysManager::slotexport()
     QString servers = gr.readEntry("Server_List");
     delete m_config;
 
-    QStringList *serverList = new QStringList(servers.split(","));
+    QStringList *serverList = new QStringList(servers.split(','));
 
     KeyExport *page = new KeyExport(dial, serverList);
     delete serverList;
@@ -1545,7 +1545,7 @@ void KeysManager::slotProcessExportClip(const QString &keys)
 void KeysManager::showKeyInfo(const QString &keyID)
 {
 	KgpgInterface *iface = new KgpgInterface;
-	KgpgKeyList listkeys = iface->readJoinedKeys(TRUST_UNKNOWN, QStringList(keyID));
+	KgpgKeyList listkeys = iface->readJoinedKeys(TRUST_MINIMUM, QStringList(keyID));
 	delete iface;
 
 	if (listkeys.count() == 0)
@@ -1888,7 +1888,6 @@ void KeysManager::signuid()
 	keyCount = 0;
 	delete opts;
 
-	refreshList.clear();
 	m_signuids = true;
 	signLoop();
 }
@@ -1921,12 +1920,13 @@ void KeysManager::signLoop()
 		signList.clear();
 		for (int i = 0; i < refreshList.count(); i++)
 			imodel->refreshKey(refreshList.at(i));
+		refreshList.clear();
 	}
 }
 
 void KeysManager::signatureResult(int success, const QString &keyId, KgpgInterface *interface)
 {
-    delete interface;
+	interface->deleteLater();
 
 	KGpgKeyNode *nd = imodel->getRootNode()->findKey(keyId);
 
@@ -2034,7 +2034,7 @@ bool KeysManager::importRemoteKey(const QString &keyIDs)
 
 void KeysManager::importRemoteFinished(KGpgTransaction *t)
 {
-	delete t;
+	t->deleteLater();
 	imodel->refreshKeys();
 }
 
