@@ -55,7 +55,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
     defaultServerList += ",hkp://search.keyserver.net,hkp://wwwkeys.pgp.net,hkp://pgp.dtype.org,hkp://wwwkeys.us.pgp.net";
 
 	KConfigGroup gr = m_config->group("Servers");
-	serverList = gr.readEntry("Server_List", defaultServerList).split(",");
+	serverList = gr.readEntry("Server_List", defaultServerList).split(',');
     keyServer = KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
 
 	/* Remove everything after a whitespace. This will normally be
@@ -162,7 +162,7 @@ void kgpgOptions::slotChangeHome()
                 }
             }
             else
-                confPath = QString();
+                confPath.clear();
         }
     }
 
@@ -241,7 +241,8 @@ void kgpgOptions::slotDefaultKeyServer()
 {
 	QListWidgetItem *curr = m_page6->ServerBox->currentItem();
 	// FIXME: no i18n concatenation, make this a single i18n call
-	curr->setText(curr->text() + ' ' + i18nc("Mark default keyserver in GUI", "(Default)"));
+	if (!curr->text().contains(' '))
+		curr->setText(curr->text() + ' ' + i18nc("Mark default keyserver in GUI", "(Default)"));
 
 	for (int i = 0; i < m_page6->ServerBox->count(); i++) {
 		QListWidgetItem *cur = m_page6->ServerBox->item(i);
@@ -303,7 +304,7 @@ void kgpgOptions::updateWidgetsDefault()
     m_page4->gpg_bin_path->setText(defaultBinPath);
 
     m_page6->ServerBox->clear();
-    m_page6->ServerBox->addItems(defaultServerList.split(","));
+    m_page6->ServerBox->addItems(defaultServerList.split(','));
 
     kDebug(2100) << "Finishing default options" ;
 }
@@ -373,7 +374,7 @@ void kgpgOptions::updateSettings()
     }
 
     QString currList;
-    serverList = QStringList();
+    serverList.clear();
 	for (int i = 0; i < m_page6->ServerBox->count(); i++) {
 		QListWidgetItem *cur = m_page6->ServerBox->item(i);
 		if (cur->text().contains(' '))		// it is the default keyserver
