@@ -16,45 +16,49 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
  */
-
 #include "konfigurator.h"
-#include "walletconfigwidget.h"
-#include <dcopclient.h>
-#include <dcopref.h>
+
+#include <QtDBus/QtDBus>
 #include <kaboutdata.h>
 #include <kapplication.h>
-#include <kconfig.h>
+#include <ksharedconfig.h>
 #include <kdialog.h>
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
 #include <kinputdialog.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kwallet.h>
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qlistview.h>
-#include <qpushbutton.h>
-#include <qspinbox.h>
+#include <QCheckBox>
+#include <q3listview.h>
+#include <QPushButton>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <ktoolinvocation.h>
+#include <kconfiggroup.h>
+#define KWALLETMANAGERINTERFACE "org.kde.KWallet"
 
-typedef KGenericFactory<KWalletConfig, QWidget> KWalletFactory;
-K_EXPORT_COMPONENT_FACTORY(kcm_kwallet, KWalletFactory("kcmkwallet"))
+K_PLUGIN_FACTORY(KWalletFactory, registerPlugin<KWalletConfig>();)
+K_EXPORT_PLUGIN(KWalletFactory("kcmkwallet"))
 
-KWalletConfig::KWalletConfig(QWidget *parent, const char *name, const QStringList&)
-: KCModule(KWalletFactory::instance(), parent, name) {
+
+KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList& args)
+: KCModule(KWalletFactory::componentData(), parent, args),
+  _cfg(KSharedConfig::openConfig("kwalletrc", KConfig::NoGlobals)) {
 
 	KAboutData *about =
-		new KAboutData(I18N_NOOP("kcmkwallet"),
-				I18N_NOOP("KDE Wallet Control Module"),
-				0, 0, KAboutData::License_GPL,
-				I18N_NOOP("(c) 2003 George Staikos"));
-		about->addAuthor("George Staikos", 0, "staikos@kde.org");
+		new KAboutData(I18N_NOOP("kcmkwallet"), 0,
+				ki18n("KDE Wallet Control Module"),
+				0, KLocalizedString(), KAboutData::License_GPL,
+				ki18n("(c) 2003 George Staikos"));
+		about->addAuthor(ki18n("George Staikos"), KLocalizedString(), "staikos@kde.org");
 	setAboutData( about );
 
-	_cfg = new KConfig("kwalletrc", false, false);
-
-	QVBoxLayout *vbox = new QVBoxLayout(this, 0, KDialog::spacingHint());
-	vbox->add(_wcw = new WalletConfigWidget(this));
+	QVBoxLayout *vbox = new QVBoxLayout(this);
+	vbox->setSpacing(KDialog::spacingHint());
+	vbox->setMargin(0);
+        _wcw = new WalletConfigWidget(this);
+	vbox->addWidget(_wcw);
 
 	connect(_wcw->_enabled, SIGNAL(clicked()), this, SLOT(configChanged()));
 	connect(_wcw->_launchManager, SIGNAL(clicked()), this, SLOT(configChanged()));
@@ -70,13 +74,13 @@ KWalletConfig::KWalletConfig(QWidget *parent, const char *name, const QStringLis
 	connect(_wcw->_newLocalWallet, SIGNAL(clicked()), this, SLOT(newLocalWallet()));
 	connect(_wcw->_localWallet, SIGNAL(activated(int)), this, SLOT(configChanged()));
 	connect(_wcw->_defaultWallet, SIGNAL(activated(int)), this, SLOT(configChanged()));
-	connect(_wcw->_accessList, SIGNAL(contextMenuRequested(QListViewItem*, const QPoint&, int)), this, SLOT(contextMenuRequested(QListViewItem*, const QPoint&, int)));
+	connect(_wcw->_accessList, SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint&, int)), this, SLOT(contextMenuRequested(Q3ListViewItem*, const QPoint&, int)));
 
 	_wcw->_accessList->setAllColumnsShowFocus(true);
 	updateWalletLists();
 	load();
 
-	if (DCOPClient::mainClient()->isApplicationRegistered("kwalletmanager")) {
+	if (QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.kwalletmanager")) {
 		_wcw->_launch->hide();
 	}
 
@@ -84,8 +88,6 @@ KWalletConfig::KWalletConfig(QWidget *parent, const char *name, const QStringLis
 
 
 KWalletConfig::~KWalletConfig() {
-	delete _cfg;
-	_cfg = 0L;
 }
 
 
@@ -98,8 +100,8 @@ void KWalletConfig::updateWalletLists() {
 	_wcw->_defaultWallet->clear();
 
 	QStringList wl = KWallet::Wallet::walletList();
-	_wcw->_localWallet->insertStringList(wl);
-	_wcw->_defaultWallet->insertStringList(wl);
+	_wcw->_localWallet->addItems(wl);
+	_wcw->_defaultWallet->addItems(wl);
 
 	if (wl.contains(p1)) {
 		_wcw->_localWallet->setCurrentText(p1);
@@ -116,17 +118,17 @@ QString KWalletConfig::newWallet() {
 
 	QString n = KInputDialog::getText(i18n("New Wallet"),
 			i18n("Please choose a name for the new wallet:"),
-			QString::null,
+			QString(),
 			&ok,
 			this);
 
 	if (!ok) {
-		return QString::null;
+		return QString();
 	}
 
-	KWallet::Wallet *w = KWallet::Wallet::openWallet(n);
+	KWallet::Wallet *w = KWallet::Wallet::openWallet(n, topLevelWidget()->winId());
 	if (!w) {
-		return QString::null;
+		return QString();
 	}
 
 	delete w;
@@ -163,12 +165,12 @@ void KWalletConfig::newNetworkWallet() {
 
 
 void KWalletConfig::launchManager() {
-	if (!DCOPClient::mainClient()->isApplicationRegistered("kwalletmanager")) {
-		KApplication::startServiceByDesktopName("kwalletmanager_show");
+	if (!QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.kwalletmanager")) {
+		KToolInvocation::startServiceByDesktopName("kwalletmanager_show");
 	} else {
-		DCOPRef r("kwalletmanager", "kwalletmanager-mainwindow#1");
-		r.send("show");
-		r.send("raise");
+             QDBusInterface kwalletd("org.kde.kwalletmanager", "/kwalletmanager/MainWindow_1");
+             kwalletd.call( "show");
+             kwalletd.call( "raise" );
 	}
 }
 
@@ -177,60 +179,53 @@ void KWalletConfig::configChanged() {
 	emit changed(true);
 }
 
-void KWalletConfig::load() {
-	load( false );
-}
 
-void KWalletConfig::load(bool useDefaults) {
+void KWalletConfig::load() {
 	KConfigGroup config(_cfg, "Wallet");
-	config.setReadDefaults( useDefaults );
-	_wcw->_enabled->setChecked(config.readBoolEntry("Enabled", true));
-	_wcw->_openPrompt->setChecked(config.readBoolEntry("Prompt on Open", true));
-	_wcw->_launchManager->setChecked(config.readBoolEntry("Launch Manager", true));
-	_wcw->_autocloseManager->setChecked(! config.readBoolEntry("Leave Manager Open", false));
-	_wcw->_screensaverLock->setChecked(config.readBoolEntry("Close on Screensaver", false));
-	_wcw->_autoclose->setChecked(!config.readBoolEntry("Leave Open", false));
-	_wcw->_closeIdle->setChecked(config.readBoolEntry("Close When Idle", false));
-	_wcw->_idleTime->setValue(config.readNumEntry("Idle Timeout", 10));
+	_wcw->_enabled->setChecked(config.readEntry("Enabled", true));
+	_wcw->_openPrompt->setChecked(config.readEntry("Prompt on Open", true));
+	_wcw->_launchManager->setChecked(config.readEntry("Launch Manager", true));
+	_wcw->_autocloseManager->setChecked(! config.readEntry("Leave Manager Open", false));
+	_wcw->_screensaverLock->setChecked(config.readEntry("Close on Screensaver", false));
+	_wcw->_autoclose->setChecked(!config.readEntry("Leave Open", false));
+	_wcw->_closeIdle->setChecked(config.readEntry("Close When Idle", false));
+	_wcw->_idleTime->setValue(config.readEntry("Idle Timeout", 10));
 	if (config.hasKey("Default Wallet")) {
 		_wcw->_defaultWallet->setCurrentText(config.readEntry("Default Wallet"));
 	} else {
-		_wcw->_defaultWallet->setCurrentItem(0);
+		_wcw->_defaultWallet->setCurrentIndex(0);
 	}
 	if (config.hasKey("Local Wallet")) {
-		_wcw->_localWalletSelected->setChecked( !config.readBoolEntry("Use One Wallet") );
+		_wcw->_localWalletSelected->setChecked( !config.readEntry("Use One Wallet", false) );
 		_wcw->_localWallet->setCurrentText(config.readEntry("Local Wallet"));
 	} else {
 		_wcw->_localWalletSelected->setChecked(false);
 	}
 	_wcw->_accessList->clear();
-	_cfg->setGroup("Auto Deny");
-	QStringList denykeys = _cfg->entryMap("Auto Deny").keys();
-	_cfg->setGroup("Auto Allow");
-	QStringList keys = _cfg->entryMap("Auto Allow").keys();
+	KConfigGroup ad(_cfg, "Auto Deny");
+	KConfigGroup aa(_cfg, "Auto Allow");
+	QStringList denykeys = ad.entryMap().keys();
+	QStringList keys = aa.entryMap().keys();
 	for (QStringList::Iterator i = keys.begin(); i != keys.end(); ++i) {
-		_cfg->setGroup("Auto Allow");
-		QStringList apps = _cfg->readListEntry(*i);
-		_cfg->setGroup("Auto Deny");
-		QStringList denyapps = _cfg->readListEntry(*i);
+		QStringList apps = aa.readEntry(*i,QStringList());
+		QStringList denyapps = ad.readEntry(*i, QStringList());
 		denykeys.remove(*i);
-		QListViewItem *lvi = new QListViewItem(_wcw->_accessList, *i);
+		Q3ListViewItem *lvi = new Q3ListViewItem(_wcw->_accessList, *i);
 		for (QStringList::Iterator j = apps.begin(); j != apps.end(); ++j) {
-			new QListViewItem(lvi, QString::null, *j, i18n("Always Allow"));
+			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Allow"));
 		}
 		for (QStringList::Iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
-			new QListViewItem(lvi, QString::null, *j, i18n("Always Deny"));
+			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Deny"));
 		}
 	}
-	_cfg->setGroup("Auto Deny");
 	for (QStringList::Iterator i = denykeys.begin(); i != denykeys.end(); ++i) {
-		QStringList denyapps = _cfg->readListEntry(*i);
-		QListViewItem *lvi = new QListViewItem(_wcw->_accessList, *i);
+		QStringList denyapps = ad.readEntry(*i,QStringList());
+		Q3ListViewItem *lvi = new Q3ListViewItem(_wcw->_accessList, *i);
 		for (QStringList::Iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
-			new QListViewItem(lvi, QString::null, *j, i18n("Always Deny"));
+			new Q3ListViewItem(lvi, QString(), *j, i18n("Always Deny"));
 		}
 	}
-	emit changed(useDefaults);
+	emit changed(false);
 }
 
 
@@ -252,7 +247,7 @@ void KWalletConfig::save() {
 		config.deleteEntry("Local Wallet");
 	}
 
-	if (_wcw->_defaultWallet->currentItem() != -1) {
+	if (_wcw->_defaultWallet->currentIndex() != -1) {
 		config.writeEntry("Default Wallet", _wcw->_defaultWallet->currentText());
 	} else {
 		config.deleteEntry("Default Wallet");
@@ -261,37 +256,53 @@ void KWalletConfig::save() {
 	// FIXME: won't survive a language change
 	_cfg->deleteGroup("Auto Allow");
 	_cfg->deleteGroup("Auto Deny");
-	_cfg->setGroup("Auto Allow");
-	for (QListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
+	config  = _cfg->group("Auto Allow");
+	for (Q3ListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
 		QStringList al;
-		for (QListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
+		for (Q3ListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
 			if (j->text(2) == i18n("Always Allow")) {
 				al << j->text(1);
 			}
 		}
-		_cfg->writeEntry(i->text(0), al);
+		config.writeEntry(i->text(0), al);
 	}
 
-	_cfg->setGroup("Auto Deny");
-	for (QListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
+	config = _cfg->group("Auto Deny");
+	for (Q3ListViewItem *i = _wcw->_accessList->firstChild(); i; i = i->nextSibling()) {
 		QStringList al;
-		for (QListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
+		for (Q3ListViewItem *j = i->firstChild(); j; j = j->nextSibling()) {
 			if (j->text(2) == i18n("Always Deny")) {
 				al << j->text(1);
 			}
 		}
-		_cfg->writeEntry(i->text(0), al);
+		config.writeEntry(i->text(0), al);
 	}
 
 	_cfg->sync();
-	DCOPRef("kded", "kwalletd").call("reconfigure()");
-
+	
+        // this restarts kwalletd if neccessary
+	if (KWallet::Wallet::isEnabled()) {
+            QDBusInterface kwalletd("org.kde.kwalletd", "/modules/kwalletd", KWALLETMANAGERINTERFACE);
+            kwalletd.call( "reconfigure" );
+        }
 	emit changed(false);
 }
 
 
 void KWalletConfig::defaults() {
-	load( true );
+	_wcw->_enabled->setChecked(true);
+	_wcw->_openPrompt->setChecked(true);
+	_wcw->_launchManager->setChecked(true);
+	_wcw->_autocloseManager->setChecked(false);
+	_wcw->_screensaverLock->setChecked(false);
+	_wcw->_autoclose->setChecked(true);
+	_wcw->_closeIdle->setChecked(false);
+	_wcw->_idleTime->setValue(10);
+	_wcw->_defaultWallet->setCurrentIndex(0);
+	_wcw->_localWalletSelected->setChecked(false);
+        _wcw->_localWallet->setCurrentIndex( 0 );
+	_wcw->_accessList->clear();
+	emit changed(true);
 }
 
 
@@ -300,19 +311,19 @@ QString KWalletConfig::quickHelp() const {
 }
 
 
-void KWalletConfig::contextMenuRequested(QListViewItem *item, const QPoint& pos, int col) {
+void KWalletConfig::contextMenuRequested(Q3ListViewItem *item, const QPoint& pos, int col) {
 	Q_UNUSED(col)
 	if (item && item->parent()) {
-		KPopupMenu *m = new KPopupMenu(this);
-		m->insertTitle(item->parent()->text(0));
-		m->insertItem(i18n("&Delete"), this, SLOT(deleteEntry()), Key_Delete);
+		KMenu *m = new KMenu(this);
+		m->addTitle(item->parent()->text(0));
+		m->addAction(i18n("&Delete"), this, SLOT(deleteEntry()), Qt::Key_Delete);
 		m->popup(pos);
 	}
 }
 
 
 void KWalletConfig::deleteEntry() {
-	QListViewItem *item = _wcw->_accessList->selectedItem();
+	Q3ListViewItem *item = _wcw->_accessList->selectedItem();
 	if (item) {
 		delete item;
 		emit changed(true);
