@@ -18,61 +18,63 @@
    Boston, MA 02110-1301, USA.
 */
 
-
-#include "kbetterthankdialogbase.h"
 #include "kwalleteditor.h"
+#include "kbetterthankdialogbase.h"
 #include "kwmapeditor.h"
 #include "allyourbase.h"
 
-#include <dcopclient.h>
-#include <dcopref.h>
+#include <stdlib.h>
+#include <QDomElement>
+#include <QDomNode>
+#include <QDomDocument>
 #include <kaction.h>
-#include <kapplication.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kfiledialog.h>
-#include <kiconview.h>
+#include <k3iconview.h>
 #include <kinputdialog.h>
 #include <kio/netaccess.h>
-#include <klistviewsearchline.h>
+#include <k3listviewsearchline.h>
+#include <kactioncollection.h>
 #include <klocale.h>
-#include <kmdcodec.h>
+#include <kcodecs.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <ksqueezedtextlabel.h>
 #include <kstandarddirs.h>
-#include <kstdaction.h>
-#include <kstringhandler.h>
-#include <ktempfile.h>
+#include <kstandardaction.h>
 
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qclipboard.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qlistview.h>
-#include <qptrstack.h>
-#include <qpushbutton.h>
-#include <qstylesheet.h>
-#include <qtextedit.h>
-#include <qtimer.h>
-#include <qwidgetstack.h>
+#include <ktemporaryfile.h>
+#include <kxmlguifactory.h>
+#include <QCheckBox>
+#include <QClipboard>
+#include <Q3ListView>
+#include <Q3PtrStack>
+#include <QPushButton>
+#include <Q3TextEdit>
+#include <QTimer>
+#include <Q3WidgetStack>
+#include <QSet>
+#include <QTextStream>
+#include <QList>
+#include <QVBoxLayout>
 
 #include <assert.h>
-#include <stdlib.h>
+#include <ktoolbar.h>
+#include <kicon.h>
 
 KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent, const char *name)
-: KMainWindow(parent, name), _walletName(wallet), _nonLocal(isPath) {
+: KXmlGuiWindow(parent), _walletName(wallet), _nonLocal(isPath) {
+	setObjectName(name);
 	_newWallet = false;
-	_ww = new WalletWidget(this, "Wallet Widget");
-	_copyPassAction = KStdAction::copy(this, SLOT(copyPassword()), actionCollection());
+	_ww = new WalletWidget(this);
+	_contextMenu = new KMenu(this);
 
 	QVBoxLayout *box = new QVBoxLayout(_ww->_entryListFrame);
 	box->setSpacing( KDialog::spacingHint() );
 	box->setMargin( KDialog::marginHint() );
 	_entryList = new KWalletEntryList(_ww->_entryListFrame, "Wallet Entry List");
-	box->addWidget(new KListViewSearchLineWidget(_entryList, _ww->_entryListFrame));
+	box->addWidget(new K3ListViewSearchLineWidget(_entryList, _ww->_entryListFrame));
 	box->addWidget(_entryList);
 
 	_ww->_entryStack->setEnabled(true);
@@ -88,16 +90,16 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 
 	resize(600, 400);
 
-	connect(_entryList, SIGNAL(selectionChanged(QListViewItem*)),
-		this, SLOT(entrySelectionChanged(QListViewItem*)));
+	connect(_entryList, SIGNAL(selectionChanged(Q3ListViewItem*)),
+		this, SLOT(entrySelectionChanged(Q3ListViewItem*)));
 	connect(_entryList,
-		SIGNAL(contextMenuRequested(QListViewItem*,const QPoint&,int)),
+		SIGNAL(contextMenuRequested(Q3ListViewItem*,const QPoint&,int)),
 		this,
-		SLOT(listContextMenuRequested(QListViewItem*,const QPoint&,int)));
+		SLOT(listContextMenuRequested(Q3ListViewItem*,const QPoint&,int)));
 	connect(_entryList,
-		SIGNAL(itemRenamed(QListViewItem*, int, const QString&)),
+		SIGNAL(itemRenamed(Q3ListViewItem*, int, const QString&)),
 		this,
-		SLOT(listItemRenamed(QListViewItem*, int, const QString&)));
+		SLOT(listItemRenamed(Q3ListViewItem*, int, const QString&)));
 
 	connect(_ww->_passwordValue, SIGNAL(textChanged()),
 		this, SLOT(entryEditted()));
@@ -124,7 +126,7 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 		connect(_w, SIGNAL(folderListUpdated()), this, SLOT(updateFolderList()));
 		updateFolderList();
 	} else {
-		kdDebug(2300) << "Wallet open failed!" << endl;
+		kDebug(2300) << "Wallet open failed!" ;
 	}
 
 	createActions();
@@ -150,7 +152,7 @@ KWalletEditor::~KWalletEditor() {
 }
 
 void KWalletEditor::layout() {
-	QValueList<int> sz = _ww->_splitter->sizes();
+	QList<int> sz = _ww->_splitter->sizes();
 	int sum = sz[0] + sz[1];
 	sz[0] = sum/2;
 	sz[1] = sum/2;
@@ -158,50 +160,71 @@ void KWalletEditor::layout() {
 }
 
 void KWalletEditor::createActions() {
-	_newFolderAction = new KAction(i18n("&New Folder..."), "folder_new",
-			0, this, SLOT(createFolder()), actionCollection(),
-			"create_folder");
+        _newFolderAction = actionCollection()->addAction( "create_folder" );
+        _newFolderAction->setText( i18n("&New Folder...") );
+        _newFolderAction->setIcon( KIcon("folder-new") );
+	connect(_newFolderAction, SIGNAL(triggered(bool) ), SLOT(createFolder()));
 	connect(this, SIGNAL(enableFolderActions(bool)),
 		_newFolderAction, SLOT(setEnabled(bool)));
 
-	_deleteFolderAction = new KAction(i18n("&Delete Folder"), 0, 0,
-			this, SLOT(deleteFolder()), actionCollection(),
-			"delete_folder");
+        _deleteFolderAction = actionCollection()->addAction("delete_folder" );
+        _deleteFolderAction->setText( i18n("&Delete Folder") );
+	connect(_deleteFolderAction, SIGNAL(triggered(bool) ), SLOT(deleteFolder()));
 	connect(this, SIGNAL(enableContextFolderActions(bool)),
 		_deleteFolderAction, SLOT(setEnabled(bool)));
 	connect(this, SIGNAL(enableFolderActions(bool)),
 		_deleteFolderAction, SLOT(setEnabled(bool)));
 
-	_passwordAction = new KAction(i18n("Change &Password..."), 0, 0, this,
-			SLOT(changePassword()), actionCollection(),
-			"change_password");
+        _passwordAction = actionCollection()->addAction( "change_password" );
+        _passwordAction->setText( i18n("Change &Password...") );
+	connect(_passwordAction, SIGNAL(triggered(bool) ), SLOT(changePassword()));
 	connect(this, SIGNAL(enableWalletActions(bool)),
 		_passwordAction, SLOT(setEnabled(bool)));
 
-	_mergeAction = new KAction(i18n("&Merge Wallet..."), 0, 0, this,
-			SLOT(importWallet()), actionCollection(),
-			"merge");
+        _mergeAction = actionCollection()->addAction( "merge");
+        _mergeAction->setText( i18n("&Merge Wallet...") );
+	connect(_mergeAction, SIGNAL(triggered(bool) ), SLOT(importWallet()));
 	connect(this, SIGNAL(enableWalletActions(bool)),
 		_mergeAction, SLOT(setEnabled(bool)));
 
-	_importAction = new KAction(i18n("&Import XML..."), 0, 0, this,
-			SLOT(importXML()), actionCollection(),
-			"import");
+        _importAction= actionCollection()->addAction( "import" );
+        _importAction->setText( i18n("&Import XML...") );
+	connect(_importAction, SIGNAL(triggered(bool) ), SLOT(importXML()));
 	connect(this, SIGNAL(enableWalletActions(bool)),
 		_importAction, SLOT(setEnabled(bool)));
 
-	_exportAction = new KAction(i18n("&Export..."), 0, 0, this,
-			SLOT(exportXML()), actionCollection(),
-			"export");
+        _exportAction = actionCollection()->addAction( "export" );
+        _exportAction->setText( i18n("&Export...") );
+	connect(_exportAction, SIGNAL(triggered(bool) ), SLOT(exportXML()));
 	connect(this, SIGNAL(enableWalletActions(bool)),
 		_exportAction, SLOT(setEnabled(bool)));
 
-	_saveAsAction = KStdAction::saveAs(this, SLOT(saveAs()), actionCollection());
+	_saveAsAction = KStandardAction::saveAs(this, SLOT(saveAs()), actionCollection());
 	connect(this, SIGNAL(enableWalletActions(bool)),
 		_saveAsAction, SLOT(setEnabled(bool)));
 
-	KStdAction::quit(this, SLOT(close()), actionCollection());
-	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
+	_copyPassAction = KStandardAction::copy(this, SLOT(copyPassword()), actionCollection());
+	
+	_newEntryAction = actionCollection()->addAction( "new_entry" );
+	_newEntryAction->setText( i18n( "&New..." ) );
+	_newEntryAction->setShortcut( Qt::Key_Insert );
+	connect(_newEntryAction, SIGNAL(triggered(bool)), SLOT(newEntry()));
+	_newEntryAction->setEnabled(false);
+	
+	_renameEntryAction = actionCollection()->addAction( "rename_entry" );
+	_renameEntryAction->setText( i18n( "&Rename" ) );
+	_renameEntryAction->setShortcut( Qt::Key_F2 );
+	connect(_renameEntryAction, SIGNAL(triggered(bool)), SLOT(renameEntry()));
+	_renameEntryAction->setEnabled(false);
+	
+	_deleteEntryAction = actionCollection()->addAction( "delete_entry" );
+	_deleteEntryAction->setText( i18n( "&Delete" ) );
+	_deleteEntryAction->setShortcut( Qt::Key_Delete );
+	connect(_deleteEntryAction, SIGNAL(triggered(bool)), SLOT(deleteEntry()));
+	_deleteEntryAction->setEnabled(false);
+
+	KStandardAction::quit(this, SLOT(close()), actionCollection());
+	KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
 	emit enableWalletActions(false);
 	emit enableFolderActions(false);
@@ -216,6 +239,7 @@ void KWalletEditor::walletClosed() {
 	_ww->setEnabled(false);
 	emit enableWalletActions(false);
 	emit enableFolderActions(false);
+	this->hide();
 	KMessageBox::sorry(this, i18n("This wallet was forced closed.  You must reopen it to continue working with it."));
 	deleteLater();
 }
@@ -223,9 +247,9 @@ void KWalletEditor::walletClosed() {
 
 void KWalletEditor::updateFolderList(bool checkEntries) {
 	QStringList fl = _w->folderList();
-	QPtrStack<QListViewItem> trash;
+	Q3PtrStack<Q3ListViewItem> trash;
 
-	for (QListViewItem *i = _entryList->firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = _entryList->firstChild(); i; i = i->nextSibling()) {
 		KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(i);
 		if (!fi) {
 			continue;
@@ -269,7 +293,7 @@ void KWalletEditor::updateFolderList(bool checkEntries) {
 					break;
 				case KWallet::Wallet::Unknown:
 				default:
-					new QListViewItem(ui, *j);
+					new Q3ListViewItem(ui, *j);
 					break;
 			}
 		}
@@ -286,14 +310,14 @@ void KWalletEditor::updateFolderList(bool checkEntries) {
 
 void KWalletEditor::deleteFolder() {
 	if (_w) {
-		QListViewItem *i = _entryList->currentItem();
+		Q3ListViewItem *i = _entryList->currentItem();
 		if (i) {
 			KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(i);
 			if (!fi) {
 				return;
 			}
 
-			int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the folder '%1' from the wallet?").arg(fi->name()),"",KStdGuiItem::del());
+			int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the folder '%1' from the wallet?", fi->name()),"",KStandardGuiItem::del());
 			if (rc == KMessageBox::Continue) {
 				bool rc = _w->removeFolder(fi->name());
 				if (!rc) {
@@ -318,7 +342,7 @@ void KWalletEditor::createFolder() {
 		do {
 			n = KInputDialog::getText(i18n("New Folder"),
 					i18n("Please choose a name for the new folder:"),
-					QString::null,
+					QString(),
 					&ok,
 					this);
 
@@ -327,11 +351,11 @@ void KWalletEditor::createFolder() {
 			}
 
 			if (_entryList->existsFolder(n)) {
-				int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that folder name is in use. Try again?"), QString::null, i18n("Try Again"), i18n("Do Not Try"));
+				int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that folder name is in use. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
 				if (rc == KMessageBox::Yes) {
 					continue;
 				}
-				n = QString::null;
+				n = QString();
 			}
 			break;
 		} while (true);
@@ -344,7 +368,7 @@ void KWalletEditor::createFolder() {
 
 void KWalletEditor::saveEntry() {
 	int rc = 1;
-	QListViewItem *item = _entryList->currentItem();
+	Q3ListViewItem *item = _entryList->currentItem();
 	_ww->_saveChanges->setEnabled(false);
 	_ww->_undoChanges->setEnabled(false);
 
@@ -366,7 +390,7 @@ void KWalletEditor::saveEntry() {
 		}
 	}
 
-	KMessageBox::sorry(this, i18n("Error saving entry. Error code: %1").arg(rc));
+	KMessageBox::sorry(this, i18n("Error saving entry. Error code: %1", rc));
 }
 
 
@@ -381,86 +405,140 @@ void KWalletEditor::entryEditted() {
 }
 
 
-void KWalletEditor::entrySelectionChanged(QListViewItem *item) {
+void KWalletEditor::entrySelectionChanged(Q3ListViewItem *item) {
 	KWalletContainerItem *ci = 0L;
 	KWalletFolderItem *fi = 0L;
 
-	switch (item->rtti()) {
-		case KWalletEntryItemClass:
-			ci = dynamic_cast<KWalletContainerItem*>(item->parent());
-			if (!ci) {
-				return;
-			}
-			fi = dynamic_cast<KWalletFolderItem*>(ci->parent());
-			if (!fi) {
-				return;
-			}
-			_w->setFolder(fi->name());
-			_deleteFolderAction->setEnabled(false);
-			if (ci->type() == KWallet::Wallet::Password) {
-				QString pass;
-				if (_w->readPassword(item->text(0), pass) == 0) {
-					_ww->_entryStack->raiseWidget(int(4));
-					_ww->_entryName->setText(i18n("Password: %1")
-							.arg(item->text(0)));
-					_ww->_passwordValue->setText(pass);
-					_ww->_saveChanges->setEnabled(false);
-					_ww->_undoChanges->setEnabled(false);
-				}
-			} else if (ci->type() == KWallet::Wallet::Map) {
-				_ww->_entryStack->raiseWidget(int(2));
-				_mapEditorShowHide->setChecked(false);
-				showHideMapEditorValue(false);
-				if (_w->readMap(item->text(0), _currentMap) == 0) {
-					_mapEditor->reload();
-					_ww->_entryName->setText(i18n("Name-Value Map: %1").arg(item->text(0)));
-					_ww->_saveChanges->setEnabled(false);
-					_ww->_undoChanges->setEnabled(false);
-				}
-			} else if (ci->type() == KWallet::Wallet::Stream) {
-				_ww->_entryStack->raiseWidget(int(3));
-				QByteArray ba;
-				if (_w->readEntry(item->text(0), ba) == 0) {
-					_ww->_entryName->setText(i18n("Binary Data: %1")
-							.arg(item->text(0)));
-					_ww->_saveChanges->setEnabled(false);
-					_ww->_undoChanges->setEnabled(false);
-				}
-			}
-			break;
+	// clear the context menu
+	_contextMenu->clear();
+	_contextMenu->setEnabled(true);
+	// disable the entry actions (reenable them on adding)
+	_newEntryAction->setEnabled(false);
+	_renameEntryAction->setEnabled(false);
+	_deleteEntryAction->setEnabled(false);
 
-		case KWalletContainerItemClass:
-			fi = dynamic_cast<KWalletFolderItem*>(item->parent());
-			if (!fi) {
-				return;
-			}
-			_w->setFolder(fi->name());
-			_deleteFolderAction->setEnabled(false);
-			_ww->_entryName->clear();
-			_ww->_entryStack->raiseWidget(int(0));
-			break;
-
-		case KWalletFolderItemClass:
-			fi = dynamic_cast<KWalletFolderItem*>(item);
-			if (!fi) {
-				return;
-			}
-			_w->setFolder(fi->name());
-			_deleteFolderAction->setEnabled(true);
-			_ww->_entryName->clear();
-			_ww->_entryStack->raiseWidget(int(0));
-			break;
-	}	
+	if (item)
+	{
+		// set the context menu's title
+		_contextMenu->addTitle(_contextMenu->fontMetrics().elidedText(
+			item->text(0), Qt::ElideMiddle, 200 ) );
+	
+		switch (item->rtti()) {
+			case KWalletEntryItemClass:
+				ci = dynamic_cast<KWalletContainerItem*>(item->parent());
+				if (!ci) {
+					return;
+				}
+				fi = dynamic_cast<KWalletFolderItem*>(ci->parent());
+				if (!fi) {
+					return;
+				}
+				_w->setFolder(fi->name());
+				_deleteFolderAction->setEnabled(false);
+				
+				// add standard menu items
+				_contextMenu->addAction( _newEntryAction );
+				_contextMenu->addAction( _renameEntryAction );
+				_contextMenu->addAction( _deleteEntryAction );
+				_newEntryAction->setEnabled(true);
+				_renameEntryAction->setEnabled(true);
+				_deleteEntryAction->setEnabled(true);
+				
+				if (ci->type() == KWallet::Wallet::Password) {
+					QString pass;
+					if (_w->readPassword(item->text(0), pass) == 0) {
+						_ww->_entryStack->setCurrentIndex(4);
+						_ww->_entryName->setText(i18n("Password: %1",
+								item->text(0)));
+						_ww->_passwordValue->setText(pass);
+						_ww->_saveChanges->setEnabled(false);
+						_ww->_undoChanges->setEnabled(false);
+					}
+					// add a context-menu action for copying passwords
+					_contextMenu->addSeparator();
+					_contextMenu->addAction( _copyPassAction );
+				} else if (ci->type() == KWallet::Wallet::Map) {
+					_ww->_entryStack->setCurrentIndex(2);
+					_mapEditorShowHide->setChecked(false);
+					showHideMapEditorValue(false);
+					if (_w->readMap(item->text(0), _currentMap) == 0) {
+						_mapEditor->reload();
+						_ww->_entryName->setText(i18n("Name-Value Map: %1", item->text(0)));
+						_ww->_saveChanges->setEnabled(false);
+						_ww->_undoChanges->setEnabled(false);
+					}
+				} else if (ci->type() == KWallet::Wallet::Stream) {
+					_ww->_entryStack->setCurrentIndex(3);
+					QByteArray ba;
+					if (_w->readEntry(item->text(0), ba) == 0) {
+						_ww->_entryName->setText(i18n("Binary Data: %1",
+								item->text(0)));
+						_ww->_saveChanges->setEnabled(false);
+						_ww->_undoChanges->setEnabled(false);
+					}
+				}
+				break;
+	
+			case KWalletContainerItemClass:
+				ci = dynamic_cast<KWalletContainerItem*>(item);
+				if (!ci) {
+					return;
+				}
+				if (ci->type() == KWallet::Wallet::Unknown) {
+					// disable context menu on unknown items
+					_contextMenu->setEnabled(false);
+				} else {
+					// add the context menu action
+					_contextMenu->addAction( _newEntryAction );
+					_newEntryAction->setEnabled(true);
+				}
+			
+				fi = dynamic_cast<KWalletFolderItem*>(item->parent());
+				if (!fi) {
+					return;
+				}
+				_w->setFolder(fi->name());
+				_deleteFolderAction->setEnabled(false);
+				_ww->_entryName->clear();
+				_ww->_entryStack->setCurrentIndex(0);
+				break;
+	
+			case KWalletFolderItemClass:
+				// add the context menu actions
+				_contextMenu->addAction( _newFolderAction );
+				_contextMenu->addAction( _deleteFolderAction );
+				
+				fi = dynamic_cast<KWalletFolderItem*>(item);
+				if (!fi) {
+					return;
+				}
+				_w->setFolder(fi->name());
+				_deleteFolderAction->setEnabled(true);
+				_ww->_entryName->clear();
+				_ww->_entryStack->setCurrentIndex(0);
+				break;
+				
+			default:
+				// all items but Unknown entries return have their
+				// rtti set. Unknown items can only be deleted.
+				_contextMenu->addAction( _deleteEntryAction );
+				_deleteEntryAction->setEnabled(true);
+				break;
+		}
+	} else {
+		// no item selected. add the "new folder" action to the context menu
+		_contextMenu->addAction( _newFolderAction );
+	}
 
 	if (fi) {
 		_currentFolder = fi->name();
 		_ww->_entryTitle->setText(QString("<font size=\"+1\">%1</font>").arg(fi->text(0)));
-		_ww->_iconTitle->setPixmap(fi->getFolderIcon(KIcon::Toolbar));
+		_ww->_iconTitle->setPixmap(fi->getFolderIcon(KIconLoader::Toolbar));
 	}
 }
 
 void KWalletEditor::updateEntries(const QString& folder) {
-	QPtrStack<QListViewItem> trash;
+	Q3PtrStack<Q3ListViewItem> trash;
 
 	_w->setFolder(folder);
 	QStringList entries = _w->entryList();
@@ -477,7 +555,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 	KWalletContainerItem *ui = fi->getContainer(KWallet::Wallet::Unknown);
 
 	// Remove deleted entries
-	for (QListViewItem *i = pi->firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = pi->firstChild(); i; i = i->nextSibling()) {
 		if (!entries.contains(i->text(0))) {
 			if (i == _entryList->currentItem()) {
 				entrySelectionChanged(0L);
@@ -486,7 +564,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 		}
 	}
 
-	for (QListViewItem *i = mi->firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = mi->firstChild(); i; i = i->nextSibling()) {
 		if (!entries.contains(i->text(0))) {
 			if (i == _entryList->currentItem()) {
 				entrySelectionChanged(0L);
@@ -495,7 +573,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 		}
 	}
 
-	for (QListViewItem *i = bi->firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = bi->firstChild(); i; i = i->nextSibling()) {
 		if (!entries.contains(i->text(0))) {
 			if (i == _entryList->currentItem()) {
 				entrySelectionChanged(0L);
@@ -504,7 +582,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 		}
 	}
 
-	for (QListViewItem *i = ui->firstChild(); i; i = i->nextSibling()) {
+	for (Q3ListViewItem *i = ui->firstChild(); i; i = i->nextSibling()) {
 		if (!entries.contains(i->text(0))) {
 			if (i == _entryList->currentItem()) {
 				entrySelectionChanged(0L);
@@ -534,7 +612,7 @@ void KWalletEditor::updateEntries(const QString& folder) {
 				break;
 			case KWallet::Wallet::Unknown:
 			default:
-				new QListViewItem(ui, *i);
+				new Q3ListViewItem(ui, *i);
 				break;
 		}
 	}
@@ -544,76 +622,24 @@ void KWalletEditor::updateEntries(const QString& folder) {
 	}
 	if (!_entryList->selectedItem()) {
 		_ww->_entryName->clear();
-		_ww->_entryStack->raiseWidget(int(0));
+		_ww->_entryStack->setCurrentIndex(0);
 	}
 }
 
-void KWalletEditor::listContextMenuRequested(QListViewItem *item, const QPoint& pos, int col) {
+void KWalletEditor::listContextMenuRequested(Q3ListViewItem *item, const QPoint& pos, int col) {
+	Q_UNUSED(item)
 	Q_UNUSED(col)
 
-	if (!_walletIsOpen) {
+	if (!_walletIsOpen || !_contextMenu->isEnabled()) {
 		return;
 	}
 
-	KWalletListItemClasses menuClass = KWalletUnknownClass;
-	KWalletContainerItem *ci = 0L;
-
-	if (item) {
-		if (item->rtti() == KWalletEntryItemClass) {
-			ci = dynamic_cast<KWalletContainerItem *>(item->parent());
-			if (!ci) {
-				return;
-			}
-		} else if (item->rtti() == KWalletContainerItemClass) {
-			ci = dynamic_cast<KWalletContainerItem *>(item);
-			if (!ci) {
-				return;
-			}
-		}
-
-		if (ci && ci->type() == KWallet::Wallet::Unknown) {
-			return;
-		}
-		menuClass = static_cast<KWalletListItemClasses>(item->rtti());
-	}
-
-	KPopupMenu *m = new KPopupMenu(this);
-	if (item) {
-		QString title = item->text(0);
-		// I think 200 pixels is wide enough for a title
-		title = KStringHandler::cPixelSqueeze(title, m->fontMetrics(), 200);
-		m->insertTitle(title);
-		switch (menuClass) {
-			case KWalletEntryItemClass:
-				m->insertItem(i18n("&New..." ), this, SLOT(newEntry()), Key_Insert);
-				m->insertItem(i18n( "&Rename" ), this, SLOT(renameEntry()), Key_F2);
-				m->insertItem(i18n( "&Delete" ), this, SLOT(deleteEntry()), Key_Delete);
-				if (ci && ci->type() == KWallet::Wallet::Password) {
-					m->insertSeparator();
-					_copyPassAction->plug(m);
-				}
-				break;
-
-			case KWalletContainerItemClass:
-				m->insertItem(i18n( "&New..." ), this, SLOT(newEntry()), Key_Insert);
-				break;
-
-			case KWalletFolderItemClass:
-				_newFolderAction->plug(m);
-				_deleteFolderAction->plug(m);
-				break;
-			default:
-				abort();
-		}
-	} else {
-		_newFolderAction->plug(m);
-	}
-	m->popup(pos);
+	_contextMenu->popup(pos);
 }
 
 
 void KWalletEditor::copyPassword() {
-	QListViewItem *item = _entryList->selectedItem();
+	Q3ListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
 		QString pass;
 		if (_w->readPassword(item->text(0), pass) == 0) {
@@ -624,11 +650,11 @@ void KWalletEditor::copyPassword() {
 
 
 void KWalletEditor::newEntry() {
-	QListViewItem *item = _entryList->selectedItem();
+	Q3ListViewItem *item = _entryList->selectedItem();
 	QString n;
 	bool ok;
 
-	QListViewItem *p;
+	Q3ListViewItem *p;
 	KWalletFolderItem *fi;
 
 	//set the folder where we're trying to create the new entry
@@ -649,7 +675,7 @@ void KWalletEditor::newEntry() {
 	do {
 		n = KInputDialog::getText(i18n("New Entry"),
 				i18n("Please choose a name for the new entry:"),
-				QString::null,
+				QString(),
 				&ok,
 				this);
 
@@ -659,17 +685,17 @@ void KWalletEditor::newEntry() {
 
 		// FIXME: prohibits the use of the subheadings
 		if (fi->contains(n)) {
-			int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that entry already exists. Try again?"), QString::null, i18n("Try Again"), i18n("Do Not Try"));
+			int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that entry already exists. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
 			if (rc == KMessageBox::Yes) {
 				continue;
 			}
-			n = QString::null;
+			n = QString();
 		}
 		break;
 	} while (true);
 
 	if (_w && item && !n.isEmpty()) {
-		QListViewItem *p = item;
+		Q3ListViewItem *p = item;
 		if (p->rtti() == KWalletEntryItemClass) {
 			p = item->parent();
 		}
@@ -682,16 +708,15 @@ void KWalletEditor::newEntry() {
 		_w->setFolder(fi->name());
 
 		KWalletEntryItem *ni = new KWalletEntryItem(_w, p, n);
-		_entryList->setSelected(ni,true);
-		_entryList->ensureItemVisible(ni);
 
 		KWalletContainerItem *ci = dynamic_cast<KWalletContainerItem*>(p);
 		if (!ci) {
 			KMessageBox::error(this, i18n("An unexpected error occurred trying to add the new entry"));
+			delete ni;
 			return;
 		}
 		if (ci->type() == KWallet::Wallet::Password) {
-			_w->writePassword(n, QString::null);
+			_w->writePassword(n, QString());
 		} else if (ci->type() == KWallet::Wallet::Map) {
 			_w->writeMap(n, QMap<QString,QString>());
 		} else if (ci->type() == KWallet::Wallet::Stream) {
@@ -699,6 +724,10 @@ void KWalletEditor::newEntry() {
 		} else {
 			abort();
 		}
+
+		_entryList->setSelected(ni,true);
+		_entryList->ensureItemVisible(ni);
+
 		fi->refresh();
 		_ww->_entryTitle->setText(QString("<font size=\"+1\">%1</font>").arg(fi->text(0)));
 	}
@@ -706,7 +735,7 @@ void KWalletEditor::newEntry() {
 
 
 void KWalletEditor::renameEntry() {
-	QListViewItem *item = _entryList->selectedItem();
+	Q3ListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
 		item->startRename(0);
 	}
@@ -714,7 +743,7 @@ void KWalletEditor::renameEntry() {
 
 
 // Only supports renaming of KWalletEntryItem derived classes.
-void KWalletEditor::listItemRenamed(QListViewItem* item, int, const QString& t) {
+void KWalletEditor::listItemRenamed(Q3ListViewItem* item, int, const QString& t) {
 	if (item) {
 		KWalletEntryItem *i = dynamic_cast<KWalletEntryItem*>(item);
 		if (!i) {
@@ -734,11 +763,11 @@ void KWalletEditor::listItemRenamed(QListViewItem* item, int, const QString& t)
 				return;
 			}
 			if (ci->type() == KWallet::Wallet::Password) {
-				_ww->_entryName->setText(i18n("Password: %1").arg(item->text(0)));
+				_ww->_entryName->setText(i18n("Password: %1", item->text(0)));
 			} else if (ci->type() == KWallet::Wallet::Map) {
-				_ww->_entryName->setText(i18n("Name-Value Map: %1").arg(item->text(0)));
+				_ww->_entryName->setText(i18n("Name-Value Map: %1", item->text(0)));
 			} else if (ci->type() == KWallet::Wallet::Stream) {
-				_ww->_entryName->setText(i18n("Binary Data: %1").arg(item->text(0)));
+				_ww->_entryName->setText(i18n("Binary Data: %1", item->text(0)));
 			}
 		} else {
 			i->setText(0, i->oldName());
@@ -748,9 +777,9 @@ void KWalletEditor::listItemRenamed(QListViewItem* item, int, const QString& t)
 
 
 void KWalletEditor::deleteEntry() {
-	QListViewItem *item = _entryList->selectedItem();
+	Q3ListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
-		int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the item '%1'?").arg(item->text(0)),"",KStdGuiItem::del());
+		int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the item '%1'?", item->text(0)),"",KStandardGuiItem::del());
 		if (rc == KMessageBox::Continue) {
 			KWalletFolderItem *fi = dynamic_cast<KWalletFolderItem *>(item->parent()->parent());
 			if (!fi) {
@@ -767,7 +796,7 @@ void KWalletEditor::deleteEntry() {
 }
 
 void KWalletEditor::changePassword() {
-	KWallet::Wallet::changePassword(_walletName);
+	KWallet::Wallet::changePassword(_walletName, winId());
 }
 
 
@@ -790,12 +819,12 @@ void KWalletEditor::walletOpened(bool success) {
 
 
 void KWalletEditor::hidePasswordContents() {
-	_ww->_entryStack->raiseWidget(int(4));
+	_ww->_entryStack->setCurrentIndex(4);
 }
 
 
 void KWalletEditor::showPasswordContents() {
-	_ww->_entryStack->raiseWidget(int(1));
+	_ww->_entryStack->setCurrentIndex(1);
 }
 
 
@@ -811,14 +840,14 @@ void KWalletEditor::showHideMapEditorValue(bool show) {
 enum MergePlan { Prompt = 0, Always = 1, Never = 2, Yes = 3, No = 4 };
 
 void KWalletEditor::importWallet() {
-	KURL url = KFileDialog::getOpenURL(QString::null, "*.kwl", this);
+	KUrl url = KFileDialog::getOpenUrl(KUrl(), "*.kwl", this);
 	if (url.isEmpty()) {
 		return;
 	}
 
 	QString tmpFile;
 	if (!KIO::NetAccess::download(url, tmpFile, this)) {
-		KMessageBox::sorry(this, i18n("Unable to access wallet '<b>%1</b>'.").arg(url.prettyURL()));
+		KMessageBox::sorry(this, i18n("Unable to access wallet '<b>%1</b>'.", url.prettyUrl()));
 		return;
 	}
 
@@ -836,8 +865,9 @@ void KWalletEditor::importWallet() {
 			}
 
 			_w->setFolder(*f);
-			
+
 			QMap<QString, QMap<QString, QString> > map;
+			QSet<QString> mergedkeys; // prevents re-merging already merged entries.
 			int rc;
 			rc = w->readMapList("*", map);
 			if (rc == 0) {
@@ -847,7 +877,7 @@ void KWalletEditor::importWallet() {
 					if (hasEntry && mp == Prompt) {
 						KBetterThanKDialogBase *bd;
 						bd = new KBetterThanKDialogBase(this);
-						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(me.key())));
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", Qt::escape(*f), Qt::escape(me.key())));
 						mp = (MergePlan)bd->exec();
 						delete bd;
 						bool ok = false;
@@ -864,7 +894,8 @@ void KWalletEditor::importWallet() {
 					} else if (hasEntry && mp == Never) {
 						continue;
 					}
-					_w->writeMap(me.key(), me.data());
+					_w->writeMap(me.key(), me.value());
+					mergedkeys.insert(me.key()); // remember this key has been merged
 				}
 			}
 
@@ -877,7 +908,7 @@ void KWalletEditor::importWallet() {
 					if (hasEntry && mp == Prompt) {
 						KBetterThanKDialogBase *bd;
 						bd = new KBetterThanKDialogBase(this);
-						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(pe.key())));
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", Qt::escape(*f), Qt::escape(pe.key())));
 						mp = (MergePlan)bd->exec();
 						delete bd;
 						bool ok = false;
@@ -894,7 +925,8 @@ void KWalletEditor::importWallet() {
 					} else if (hasEntry && mp == Never) {
 						continue;
 					}
-					_w->writePassword(pe.key(), pe.data());
+					_w->writePassword(pe.key(), pe.value());
+					mergedkeys.insert(pe.key()); // remember this key has been merged
 				}
 			}
 
@@ -903,11 +935,15 @@ void KWalletEditor::importWallet() {
 			if (rc == 0) {
 				QMap<QString, QByteArray>::ConstIterator ee;
 				for (ee = ent.constBegin(); ee != ent.constEnd(); ++ee) {
+					// prevent re-merging already merged entries.
+					if (mergedkeys.contains(ee.key())) {
+						continue;
+					}
 					bool hasEntry = _w->hasEntry(ee.key());
 					if (hasEntry && mp == Prompt) {
 						KBetterThanKDialogBase *bd;
 						bd = new KBetterThanKDialogBase(this);
-						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(ee.key())));
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", Qt::escape(*f), Qt::escape(ee.key())));
 						mp = (MergePlan)bd->exec();
 						delete bd;
 						bool ok = false;
@@ -924,7 +960,7 @@ void KWalletEditor::importWallet() {
 					} else if (hasEntry && mp == Never) {
 						continue;
 					}
-					_w->writeEntry(ee.key(), ee.data());
+					_w->writeEntry(ee.key(), ee.value());
 				}
 			}
 		}
@@ -939,33 +975,33 @@ void KWalletEditor::importWallet() {
 
 
 void KWalletEditor::importXML() {
-	KURL url = KFileDialog::getOpenURL(QString::null, "*.xml", this);
+	KUrl url = KFileDialog::getOpenUrl( KUrl(), "*.xml", this);
 	if (url.isEmpty()) {
 		return;
 	}
 
 	QString tmpFile;
 	if (!KIO::NetAccess::download(url, tmpFile, this)) {
-		KMessageBox::sorry(this, i18n("Unable to access XML file '<b>%1</b>'.").arg(url.prettyURL()));
+		KMessageBox::sorry(this, i18n("Unable to access XML file '<b>%1</b>'.", url.prettyUrl()));
 		return;
 	}
 
 	QFile qf(tmpFile);
-	if (!qf.open(IO_ReadOnly)) {
-		KMessageBox::sorry(this, i18n("Error opening XML file '<b>%1</b>' for input.").arg(url.prettyURL()));
+	if (!qf.open(QIODevice::ReadOnly)) {
+		KMessageBox::sorry(this, i18n("Error opening XML file '<b>%1</b>' for input.", url.prettyUrl()));
 		KIO::NetAccess::removeTempFile(tmpFile);
 		return;
 	}
 
 	QDomDocument doc(tmpFile);
 	if (!doc.setContent(&qf)) {
-		KMessageBox::sorry(this, i18n("Error reading XML file '<b>%1</b>' for input.").arg(url.prettyURL()));
+		KMessageBox::sorry(this, i18n("Error reading XML file '<b>%1</b>' for input.", url.prettyUrl()));
 		KIO::NetAccess::removeTempFile(tmpFile);
 		return;
 	}
 
 	QDomElement top = doc.documentElement();
-	if (top.tagName().lower() != "wallet") {
+	if (top.tagName().toLower() != "wallet") {
 		KMessageBox::sorry(this, i18n("Error: XML file does not contain a wallet."));
 		KIO::NetAccess::removeTempFile(tmpFile);
 		return;
@@ -975,7 +1011,7 @@ void KWalletEditor::importXML() {
 	MergePlan mp = Prompt;
 	while (!n.isNull()) {
 		QDomElement e = n.toElement();
-		if (e.tagName().lower() != "folder") {
+		if (e.tagName().toLower() != "folder") {
 			n = n.nextSibling();
 			continue;
 		}
@@ -992,13 +1028,13 @@ void KWalletEditor::importXML() {
 		QDomNode enode = e.firstChild();
 		while (!enode.isNull()) {
 			e = enode.toElement();
-			QString type = e.tagName().lower();
+			QString type = e.tagName().toLower();
 			QString ename = e.attribute("name");
 			bool hasEntry = _w->hasEntry(ename);
 			if (hasEntry && mp == Prompt) {
 				KBetterThanKDialogBase *bd;
 				bd = new KBetterThanKDialogBase(this);
-				bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(fname)).arg(QStyleSheet::escape(ename)));
+				bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?", Qt::escape(fname), Qt::escape(ename)));
 				mp = (MergePlan)bd->exec();
 				delete bd;
 				bool ok = false;
@@ -1020,13 +1056,13 @@ void KWalletEditor::importXML() {
 			if (type == "password") {
 				_w->writePassword(ename, e.text());
 			} else if (type == "stream") {
-				_w->writeEntry(ename, KCodecs::base64Decode(e.text().latin1()));
+				_w->writeEntry(ename, KCodecs::base64Decode(e.text().toLatin1()));
 			} else if (type == "map") {
 				QMap<QString,QString> map;
 				QDomNode mapNode = e.firstChild();
 				while (!mapNode.isNull()) {
 					QDomElement mape = mapNode.toElement();
-					if (mape.tagName().lower() == "mapentry") {
+					if (mape.tagName().toLower() == "mapentry") {
 						map[mape.attribute("name")] = mape.text();
 					}
 					mapNode = mapNode.nextSibling();
@@ -1045,9 +1081,9 @@ void KWalletEditor::importXML() {
 
 
 void KWalletEditor::exportXML() {
-	KTempFile tf;
-	tf.setAutoDelete(true);
-	QTextStream& ts(*tf.textStream());
+	KTemporaryFile tf;
+	tf.open();
+	QTextStream ts(&tf);
 	QStringList fl = _w->folderList();
 
 	ts << "<wallet name=\"" << _walletName << "\">" << endl;
@@ -1061,8 +1097,8 @@ void KWalletEditor::exportXML() {
 					{
 						QString pass;
 						if (_w->readPassword(*j, pass) == 0) {
-							ts << "    <password name=\"" << QStyleSheet::escape(*j) << "\">";
-							ts << QStyleSheet::escape(pass);
+							ts << "    <password name=\"" << Qt::escape(*j) << "\">";
+							ts << Qt::escape(pass);
 							ts << "</password>" << endl;
 						}
 						break;
@@ -1071,7 +1107,7 @@ void KWalletEditor::exportXML() {
 					{
 						QByteArray ba;
 						if (_w->readEntry(*j, ba) == 0) {
-							ts << "    <stream name=\"" << QStyleSheet::escape(*j) << "\">";
+							ts << "    <stream name=\"" << Qt::escape(*j) << "\">";
 							ts << KCodecs::base64Encode(ba);
 
 							ts << "</stream>" << endl;
@@ -1082,9 +1118,9 @@ void KWalletEditor::exportXML() {
 					{
 						QMap<QString,QString> map;
 						if (_w->readMap(*j, map) == 0) {
-							ts << "    <map name=\"" << QStyleSheet::escape(*j) << "\">" << endl;
+							ts << "    <map name=\"" << Qt::escape(*j) << "\">" << endl;
 							for (QMap<QString,QString>::ConstIterator k = map.begin(); k != map.end(); ++k) {
-								ts << "      <mapentry name=\"" << QStyleSheet::escape(k.key()) << "\">" << QStyleSheet::escape(k.data()) << "</mapentry>" << endl;
+								ts << "      <mapentry name=\"" << Qt::escape(k.key()) << "\">" << Qt::escape(k.value()) << "</mapentry>" << endl;
 							}
 							ts << "    </map>" << endl;
 						}
@@ -1099,12 +1135,12 @@ void KWalletEditor::exportXML() {
 	}
 
 	ts << "</wallet>" << endl;
-	tf.close();
+	ts.flush();
 
-	KURL url = KFileDialog::getSaveURL(QString::null, "*.xml", this);
+	KUrl url = KFileDialog::getSaveUrl(KUrl(), "*.xml", this);
 
 	if (!url.isEmpty()) {
-		KIO::NetAccess::file_copy(tf.name(), url, 0600, false, false, this);
+		KIO::NetAccess::dircopy(KUrl::fromPath(tf.fileName()), url, this);
 	}
 }
 
@@ -1115,14 +1151,14 @@ void KWalletEditor::setNewWallet(bool x) {
 
 
 void KWalletEditor::saveAs() {
-	KURL url = KFileDialog::getSaveURL(QString::null, "*.kwl", this);
+	KUrl url = KFileDialog::getSaveUrl(KUrl(), "*.kwl", this);
 	if (!url.isEmpty()) {
 		// Sync() kwalletd
 		if (_nonLocal) {
-			KIO::NetAccess::file_copy(_walletName, url, 0600, false, false, this);
+			KIO::NetAccess::dircopy(_walletName, url, this);
 		} else {
-			QString path = KGlobal::dirs()->saveLocation("kwallet") + "/" + _walletName + ".kwl";
-			KIO::NetAccess::file_copy(path, url, 0600, false, false, this);
+			QString path = KGlobal::dirs()->saveLocation("kwallet") + '/' + _walletName + ".kwl";
+			KIO::NetAccess::dircopy(KUrl::fromPath(path), url, this);
 		}
 	}
 }
